[fractal/fractal-next] verification: Fix typo in verification



commit aeb1871b998dfb0d5b1c9014f15bb50f41eaf239
Author: Julian Sparber <julian sparber net>
Date:   Thu Jan 13 14:47:26 2022 +0100

    verification: Fix typo in verification

 src/session/verification/identity_verification.rs | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/src/session/verification/identity_verification.rs 
b/src/session/verification/identity_verification.rs
index fdc03b57..d74a7c65 100644
--- a/src/session/verification/identity_verification.rs
+++ b/src/session/verification/identity_verification.rs
@@ -194,7 +194,7 @@ mod imp {
                     glib::ParamSpec::new_string(
                         "display-name",
                         "Display name",
-                        "The display name of this verificaiton request",
+                        "The display name of this verification request",
                         None,
                         glib::ParamFlags::READABLE | glib::ParamFlags::EXPLICIT_NOTIFY,
                     ),
@@ -337,7 +337,7 @@ impl IdentityVerification {
         .expect("Failed to create IdentityVerification")
     }
 
     /// Creates and send a new verificaiton request
     ///
     /// If `User` is `None` a new session verification is started for our own user and send to other devices
     pub async fn create(session: &Session, user: Option<&User>) -> Self {
@@ -597,7 +597,7 @@ impl IdentityVerification {
 
         let error_message = if let Some(info) = self.cancel_info() {
             match info.cancel_code() {
-                CancelCode::User => Some(gettext("You cancelled the verificaiton process.")),
+                CancelCode::User => Some(gettext("You cancelled the verification process.")),
                 CancelCode::Timeout => Some(gettext(
                     "The verification process failed because it reached a timeout.",
                 )),
@@ -337,7 +337,7 @@ impl IdentityVerification {
     }
 
-    /// Creates and send a new verificaiton request
+    /// Creates and send a new verification request
     ///
     /// If `User` is `None` a new session verification is started for our own user and send to other devices


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]